@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_GETACLJOB_H
-#define KIMAP_GETACLJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -123,4 +122,3 @@ protected:
 
 }
 
-#endif
